@@ -30,9 +30,9 @@
 	 (br ($float ($realpart b)))
 	 (bi ($float ($imagpart b))))
     (cond ((and (numberp br) (numberp bi))
-	   (if (= bi 0) (float br 1.0L0)
-	     (complex (float br 1.0L0) 
-		      (float bi 1.0L0))))
+	   (if (= bi 0) (float br 1.0d0)
+	     (complex (float br 1.0d0) 
+		      (float bi 1.0d0))))
 	  (t a))))
 
 ;; Return true iff a is a float or a complex number with either a
@@ -946,7 +946,7 @@
 		  (setq d (if (oddp n) -1 1))
 		  (setq x (mul -1 x))
 		  (setq z (* -1 z))))
-	   (setq n (+ 0.5L0 ($float n)))
+	   (setq n (+ 0.5d0 ($float n)))
 	   (setq d (* d (sqrt (/ pi (* 2 z)))))
 	   (setq d (lisp-float-to-maxima-float d))
 	   ($expand (mul ($rectform d) ($bessel x n)))))
@@ -997,7 +997,7 @@
 		  (setq d (if (oddp n) 1 -1))
 		  (setq x (mul -1 x))
 		  (setq z (* -1 z))))
-	   (setq n (+ 0.5L0 ($float n)))
+	   (setq n (+ 0.5d0 ($float n)))
 	   (setq d (* d (sqrt (/ pi (* 2 z)))))
 	   (setq d (lisp-float-to-maxima-float d))
 	   ($expand (mul ($rectform d) ($bessel_y n x)))))
