@@ -84,6 +84,7 @@
 ;; people like to do big factorials so do them a bit faster.
 ;; by breaking into chunks.
 
+#+nil
 (defun factorial (n &aux (ans 1)  )
   (let* ((vec (make-array (if (< n 100) 1 20) :initial-element 1))
 	 (m (length vec))
@@ -95,6 +96,27 @@
 	   do (setq ans (* ans v)))
     ans))
 
+;; From Richard Fateman's paper, "Comments on Factorial Programs",
+;; http://www.cs.berkeley.edu/~fateman/papers/factorial.pdf
+;;
+;; k(n,m) = n*(n-m)*(n-2*m)*...
+;;
+;; (k n 1) is n!
+;;
+;; This is much faster (3-4 times) than the original factorial
+;; function.
+(defun k (n m) 
+  (if (<= n m)
+      n
+      (* (k n (* 2 m))
+	 (k (- n m) (* 2 m)))))
+
+
+(defun factorial (n)
+  (if (zerop n)
+      1
+      (k n 1)))
+
 (defmfun simpfact (x y z)
   (oneargcheck x)
   (setq y (simpcheck (cadr x) z))
@@ -412,13 +434,15 @@ summation when necessary."
       lo 
 
       (setq u
-        (resimplify
-          (list (if sump '(mplus) '(mtimes))
-                (let*
-                  ((foo (mbinding (lind l*i) (meval expr)))
-                   (bar (subst-if-not-freeof *i ind foo)))
-                  bar)
-                u)))
+            (if sump
+              (add u (resimplify (let*
+                                   ((foo (mbinding (lind l*i) (meval expr)))
+                                    (bar (subst-if-not-freeof *i ind foo)))
+                                   bar)))
+              (mul u (resimplify (let*
+                                   ((foo (mbinding (lind l*i) (meval expr)))
+                                    (bar (subst-if-not-freeof *i ind foo)))
+                                   bar)))))
 
       (if (= *hl 0) (return u))
 
