@@ -541,7 +541,7 @@
   (cond ((not ($listp a))
 	 (merror "Arg to `cfdisrep' not a list: ~M" a))
 	((null (cddr a)) (cadr a))
-	((zerop (cadr a))
+	((equal (cadr a) 0)
 	 (list '(mexpt) (cfdisrep1 (cddr a)) -1))
 	((cfdisrep1 (cdr a)))))
 
@@ -978,9 +978,10 @@
   (cond ((memq (asksign lo) '($zero $negative))
 	 (throw 'isumout '$inf)))
   (and (null (equal lo 1))
-       (adsum `((%sum) 
-		((mtimes) ,a -1 ((mexpt) ,*var* ,n))
-		,*var* 1 ((mplus) -1 ,lo))))
+       (let ((sign sign))
+         (adsum `((%sum)
+                  ((mtimes) ,a -1 ((mexpt) ,*var* ,n))
+                  ,*var* 1 ((mplus) -1 ,lo)))))
   (cond ((eq sign '$negative)
 	 (list '(mtimes) a ($zeta (meval (list '(mtimes) -1 n)))))
 	((throw 'isumout '$inf))))
