@@ -568,13 +568,13 @@ Maybe you want to use `not equal'."))
 	 (setq $askexp (lmul evens)
 	       sign (cdr (assol $askexp locals)))
 	 (do () (nil)
-	   (cond ((zl-member sign '($zero $z |$z| 0 0.0))
+	   (cond ((zl-member sign '($zero |$Z| |$z| 0 0.0))
 		  (tdzero $askexp) (setq sign '$zero) (return t))
-		 ((memq sign '($pn $nonzero $n |$n| $nz $nonz $non0))
+		 ((memq sign '($pn $nonzero |$N| |$n| $nz $nonz $non0))
 		  (tdpn $askexp) (setq sign '$pos) (return t))
-		 ((memq sign '($pos $p |$p| $positive))
+		 ((memq sign '($pos |$P| |$p| $positive))
 		  (tdpos $askexp) (setq sign '$pos) (return t))
-		 ((memq sign '($neg $n |$n| $negative))
+		 ((memq sign '($neg |$N| |$n| $negative))
 		  (tdneg $askexp) (setq sign '$pos) (return t)))
 	   (setq sign (ask "Is  " $askexp "  zero or nonzero?")))
 	 (if minus (flip sign) sign))
@@ -586,13 +586,13 @@ Maybe you want to use `not equal'."))
 			   ((eq '$pn sign) "  positive or negative?")
 			   (t "  positive, negative, or zero?")))
 		(ans (cdr (assol $askexp locals)))) (nil)
-	     (cond ((and (memq ans '($pos $p |$p| $positive))
+	     (cond ((and (memq ans '($pos |$P| |$p| $positive))
 			 (memq sign '($pz $pn $pnz)))
 		    (tdpos $askexp) (setq sign '$pos) (return t))
-		   ((and (memq ans '($neg $n |$n| $negative))
+		   ((and (memq ans '($neg |$N| |$n| $negative))
 			 (memq sign '($nz $pn $pnz)))
 		    (tdneg $askexp) (setq sign '$neg) (return t))
-		   ((and (zl-member ans '($zero $z |$z| 0 0.0))
+		   ((and (zl-member ans '($zero |$Z| |$z| 0 0.0))
 			 (memq sign '($pz $nz $pnz)))
 		    (tdzero $askexp) (setq sign '$zero) (return t)))
 	     (setq ans (ask "Is  " $askexp dom)))
