@@ -8,7 +8,7 @@
 ;;;     (c) Copyright 1981 Massachusetts Institute of Technology         ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(in-package "MAXIMA")
+(in-package :maxima)
 
 (macsyma-module cpoly)
 
@@ -51,15 +51,6 @@
 
 ;;; It is harder to underflow on lisp machine, but I suppose someday -BEE
 
-(eval-when
-    #+gcl (compile load)
-    #-gcl (:compile-toplevel :load-toplevel)
-    (defmacro *f  (a b) `(*$ ,a ,b))
-    (defmacro //f (a b) `(//$ ,a ,b))
-    (defmacro +f  (a b) `(+$ ,a ,b)))
-
-;;(defmacro -f  (a b) `(-$ ,a ,b))
-
 ;;(defmacro float-precision (pres)
 ;;  pres ;Ignored on Lisp Machine
 ;;  #+LISPM (let ((a (float 1)))
@@ -363,8 +354,8 @@
        (store (aref *pi-sl* i) (_f (aref *pi-sl* i) j)))
      nn)
    (log 2.0d0)
-   (float most-positive-long-float)
-   (float least-positive-long-float)
+   most-positive-double-float
+   least-positive-double-float
    double-float-epsilon
    0.0d0 0.70710677d0 0.0d0 -0.069756474d0 0.99756405d0
    0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0 0 0 nil))
@@ -686,8 +677,8 @@
 	 ((> i nn))
        (store (aref *pr-sl* i) (_f (aref *pr-sl* i) j))))
    (log 2.0)
-   (float most-positive-long-float)
-   (float least-positive-long-float)
+   most-positive-double-float
+   least-positive-double-float
    double-float-epsilon
    0.0d0 0.70710677 0.0d0 -0.069756474 0.99756405
    0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0.0d0 0 0 0 0 0 t))  
