@@ -61,6 +61,7 @@
 (defun csqfrp ($factorflag)
   (null (zl-delete 1 (oddelm (cdr (cfactor $factorflag))))))
 
+#+nil
 (defun primcyclo (n &aux *g* (nl (cfactorw n)))
   (setq nl (loop for (c e) on nl by #'cddr
 		  nconc (*make-list e c)))
@@ -69,6 +70,16 @@
 	  ((eql 0 res) nil)
 	  (t (list 0 res)))))
 
+(defun primcyclo (n)
+  (let ((*g* (gensym "PRIMCYCLO-"))
+	(nl (loop for (c e) on (cfactorw n) by #'cddr
+	       nconc (*make-list e c))))
+    (setf (symbol-value *g*) 0)
+    (let ((res (cyclotomic (list n nl))))
+      (cond ((consp res) (p-terms res))
+	    ((eql 0 res) nil)
+	    (t (list 0 res))))))
+
 (defun factxn+-1 (p) 
   (let ((*g* (car p))
 	($factorflag t)) 
@@ -1417,4 +1428,4 @@
 
 ;;(DEFMVAR *ALPHA (CAR BIGPRIMES))
 
- 
\ No newline at end of file
+ 
