@@ -188,11 +188,9 @@
 		 (not (and (memq x $aliases) (get x 'noun))))
 	    (setq y (exploden y)))
 	   ((setq y (assqr x aliaslist)) (return (msize (car y) l r lop rop)))
-	   ((null (setq y (if (eq '%derivative x)
-			      (copy-top-level '(#\% #\d #\i #\f #\f))
-			      (exploden x)))))
+       ((null (setq y (exploden x))))
+       ((safe-get x 'noun) (return (msize-atom (get x 'noun) l r)))
 	   ((char= #\$ (car y)) (setq y (slash (cdr y))))
-	   ((char= #\% (car y)) (setq y (slash (cdr y))))
 	   ((char= #\& (car y))
 	    (do ((l (cdr y) (cdr l))) ((null l))
 	      (cond ((or (zl-member (car l)
@@ -214,6 +212,7 @@
 (defun slash (x)
   (do ((l (cdr x) (cdr l))) ((null l))
     (if (or (alphanumericp (car l))
+	    (eql (car l) #\%)
 	    (eql (car l) #\_))
 	nil
 	(progn (rplacd l (cons (car l) (cdr l)))
