@@ -117,7 +117,8 @@
 	 (d-tag))
 	(nil)
       (catch 'return-from-debugger
-	(when (not (checklabel $inchar))
+	(when (or (not (checklabel $inchar))
+              (not (checklabel $outchar)))
 	  (setq $linenum (f1+ $linenum)))
 	#+akcl(si::reset-stack-limits)
 	(setq c-tag (makelabel $inchar))
@@ -282,7 +283,8 @@
 	 (displa msg) 
 	 (princ *prompt-suffix*)
 	 (mterpri)))
-  (mread-noprompt *query-io* nil))
+  (let ((res (mread-noprompt *query-io* nil)))
+       (princ *general-display-prefix*) res))
 
 
 (defmfun $read (&rest l)
@@ -385,6 +387,8 @@
 (defvar *maxima-prolog* "")
 (defvar *maxima-epilog* "")
 
+(defvar *maxima-quiet* nil)
+
 #-lispm
 (defun macsyma-top-level (&optional (input-stream *standard-input*)
 			  batch-flag)
@@ -392,20 +396,7 @@
     (if *maxima-started*
 	(format t "Maxima restarted.~%")
 	(progn
-	  (format t *maxima-prolog*)
-	  (format t "~&Maxima ~a http://maxima.sourceforge.net~%"
-		  *autoconf-version*)
-	  (format t "Using Lisp ~a ~a" (lisp-implementation-type)
-		  #-clisp (lisp-implementation-version)
-		  #+clisp (subseq (lisp-implementation-version)
-				  0 (+ 1 (search
-					  ")" (lisp-implementation-version)))))
-	  #+gcl (format t " (aka GCL)")
-	  (format t "~%")
-	  (format t "Distributed under the GNU Public License. See the file COPYING.~%")
-	  (format t "Dedicated to the memory of William Schelter.~%")
-	  (format t "This is a development version of Maxima. The function bug_report()~%")
-	  (format t "provides bug reporting information.~%")
+      (if (not *maxima-quiet*) (maxima-banner))
 	  (setq *maxima-started* t)))
     (if ($file_search "maxima-init.lisp") ($load ($file_search "maxima-init.lisp")))
     (if ($file_search "maxima-init.mac") ($batchload ($file_search "maxima-init.mac")))
@@ -420,6 +411,22 @@
 		(format t *maxima-epilog*)
 		(bye)))))))
 
+(defun maxima-banner ()
+  (format t *maxima-prolog*)
+  (format t "~&Maxima ~a http://maxima.sourceforge.net~%"
+      *autoconf-version*)
+  (format t "Using Lisp ~a ~a" (lisp-implementation-type)
+      #-clisp (lisp-implementation-version)
+      #+clisp (subseq (lisp-implementation-version)
+              0 (+ 1 (search
+                  ")" (lisp-implementation-version)))))
+  #+gcl (format t " (aka GCL)")
+  (format t "~%")
+  (format t "Distributed under the GNU Public License. See the file COPYING.~%")
+  (format t "Dedicated to the memory of William Schelter.~%")
+  (format t "This is a development version of Maxima. The function bug_report()~%")
+  (format t "provides bug reporting information.~%"))
+
 #-lispm
 (progn 
   
