@@ -835,7 +835,7 @@
 		     (- num-problems (length all-differences)) num-problems)
 	     (let ((s (if (> (length all-differences) 1) "s" "")))
 	       (format t "~%The following ~A problem~A failed: ~A~%" 
-		       (length all-differences) s all-differences))
+		       (length all-differences) s (reverse all-differences)))
 	     `((mlist),filename ,@ all-differences)))))
 	   
 (defun batch-equal-check (next-result result 
@@ -848,10 +848,14 @@
 		       (or recursive ($simple_equal result $functions)))
 		      (batch-equal-check (meval* next-result) result t)))
 	       (and (not ($bfloatp result))
-		    (let (($fpprec 12))
-		      (declare (special $fpprec))
+            ; Next test succeeds when floats are same to $FPPRINTPREC digits.
+            ; Not sure about effect on non-floats.
+		    (let (($fpprintprec 12))
+		      (declare (special $fpprintprec))
 		      (equal (mstring result) (mstring next-result))))
 	       (cond ((not  (appears-in result 'factored))
+              ; Next test succeeds when floats are same within $RATEPSILON.
+              ; Not sure about effect on non-floats.
 		      (like ($ratsimp next-result)
 			    ($ratsimp result))))
 	       (equal 0 ($ratsimp `((mplus) ,next-result 
@@ -889,6 +893,8 @@
 (defun new-file-search (name template)
   (cond ((probe-file name))
 	((atom template)
+     (if (mstringp template)
+       (setq template (subseq (maybe-invert-string-case (string template)) 1)))
 	 (let ((lis (loop for w in (split-string template "{}")
 			  when (null (position #\, w))
 			  collect w
