@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing nil) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((con
@@ -43,10 +43,10 @@
                                        -2813563.22658653 1268365.27332162
                                        -331645.172484564 45218.7689813627
                                        -2499.83048181121 24.3805296995561
-                                       3284469.85307204 -1.97068191184322e+7
-                                       5.09526024926646e+7 -7.41051482115327e+7
-                                       6.6344512274729e+7 -3.75671766607634e+7
-                                       1.32887671664218e+7 -2785618.12808645
+                                       3284469.85307204 -1.97068191184322e7
+                                       5.09526024926646e7 -7.41051482115327e7
+                                       6.6344512274729e7 -3.75671766607634e7
+                                       1.32887671664218e7 -2785618.12808645
                                        308186.404612662 -13886.089753717
                                        110.017140269247))))
   (declare (type (array double-float (65)) c)
@@ -64,7 +64,7 @@
                  (type f2cl-lib:integer4 l kk k jn j)
                  (type double-float z t2 tol t$ s2 s1 gln fn etx coef ap ak))
         (setf tol (f2cl-lib:d1mach 3))
-        (setf tol (max tol 1.0e-15))
+        (setf tol (max tol 1.e-15))
         (setf fn fnu)
         (setf z (/ (- 3.0 flgik) 2.0))
         (setf kk (f2cl-lib:int z))
