@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing nil) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((tols -6.90775527898214)
@@ -58,14 +58,172 @@
                                        -2813563.22658653 1268365.27332162
                                        -331645.172484564 45218.7689813627
                                        -2499.83048181121 24.3805296995561
-                                       3284469.85307204 -1.97068191184322e+7
-                                       5.09526024926646e+7 -7.41051482115327e+7
-                                       6.6344512274729e+7 -3.75671766607634e+7
-                                       1.32887671664218e+7 -2785618.12808645
+                                       3284469.85307204 -1.97068191184322e7
+                                       5.09526024926646e7 -7.41051482115327e7
+                                       6.6344512274729e7 -3.75671766607634e7
+                                       1.32887671664218e7 -2785618.12808645
                                        308186.404612662 -13886.089753717
                                        110.017140269247)))
-      (alfa (make-array 104 :element-type 'double-float))
-      (beta (make-array 130 :element-type 'double-float))
+      (alfa
+       (make-array 104
+                   :element-type 'double-float
+                   :initial-contents '(-0.00444444444444444
+                                       -9.22077922077922e-4
+                                       -8.84892884892885e-5 1.6592768783245e-4
+                                       2.46691372741793e-4 2.65995589346255e-4
+                                       2.61824297061501e-4 2.48730437344656e-4
+                                       2.32721040083232e-4 2.16362485712365e-4
+                                       2.00738858762752e-4 1.86267636637545e-4
+                                       1.73060775917876e-4 1.61091705929016e-4
+                                       1.50274774160908e-4 1.4050349739127e-4
+                                       1.31668816545923e-4 1.23667445598253e-4
+                                       1.16405271474738e-4 1.09798298372713e-4
+                                       1.03772410422993e-4 9.82626078369363e-5
+                                       9.32120517249503e-5 8.85710852478712e-5
+                                       8.429631057157e-5 8.03497548407791e-5
+                                       6.93735541354589e-4 2.32241745182922e-4
+                                       -1.41986273556691e-5
+                                       -1.16444931672049e-4
+                                       -1.50803558053049e-4
+                                       -1.55121924918096e-4
+                                       -1.46809756646466e-4
+                                       -1.33815503867491e-4
+                                       -1.19744975684254e-4
+                                       -1.06184319207974e-4
+                                       -9.37699549891194e-5
+                                       -8.26923045588193e-5
+                                       -7.29374348155221e-5
+                                       -6.44042357721016e-5
+                                       -5.69611566009369e-5
+                                       -5.04731044303562e-5
+                                       -4.48134868008883e-5
+                                       -3.98688727717599e-5
+                                       -3.55400532972042e-5
+                                       -3.17414256609022e-5
+                                       -2.83996793904175e-5
+                                       -2.54522720634871e-5
+                                       -2.28459297164725e-5
+                                       -2.05352753106481e-5
+                                       -1.84816217627666e-5
+                                       -1.66519330021394e-5
+                                       -3.54211971457744e-4
+                                       -1.56161263945159e-4 3.04465503594936e-5
+                                       1.30198655773243e-4 1.67471106699712e-4
+                                       1.70222587683593e-4 1.56501427608595e-4
+                                       1.36339170977445e-4 1.14886692029825e-4
+                                       9.45869093034688e-5 7.64498419250898e-5
+                                       6.07570334965197e-5 4.74394299290509e-5
+                                       3.62757512005344e-5 2.69939714979225e-5
+                                       1.93210938247939e-5 1.30056674793963e-5
+                                       7.82620866744497e-6 3.59257485819352e-6
+                                       1.44040049814252e-7 -2.65396769697939e-6
+                                       -4.91346867098486e-6
+                                       -6.72739296091248e-6
+                                       -8.17269379678658e-6
+                                       -9.31304715093561e-6
+                                       -1.02011418798016e-5 3.78194199201773e-4
+                                       2.02471952761816e-4 -6.37938506318862e-5
+                                       -2.38598230603006e-4
+                                       -3.10916256027362e-4
+                                       -3.13680115247576e-4
+                                       -2.78950273791323e-4
+                                       -2.28564082619141e-4
+                                       -1.75245280340847e-4 -1.2554406306069e-4
+                                       -8.22982872820208e-5
+                                       -4.62860730588116e-5
+                                       -1.72334302366962e-5 5.60690482304602e-6
+                                       2.31395443148287e-5 3.62642745856794e-5
+                                       4.58006124490189e-5 5.24595294959114e-5
+                                       5.68396208545815e-5 5.94349820393104e-5
+                                       6.06478527578422e-5 6.08023907788436e-5
+                                       6.0157789453946e-5 5.89199657344698e-5
+                                       5.72515823777593e-5
+                                       5.52804375585853e-5)))
+      (beta
+       (make-array 130
+                   :element-type 'double-float
+                   :initial-contents '(0.0179988721413553 0.00559964911064388
+                                       0.00288501402231133 0.00180096606761054
+                                       0.00124753110589199 9.22878876572938e-4
+                                       7.14430421727287e-4 5.71787281789705e-4
+                                       4.69431007606482e-4 3.93232835462917e-4
+                                       3.34818889318298e-4 2.88952148495752e-4
+                                       2.52211615549573e-4 2.22280580798883e-4
+                                       1.97541838033063e-4 1.76836855019718e-4
+                                       1.59316899661821e-4 1.44347930197334e-4
+                                       1.31448068119965e-4 1.20245444949303e-4
+                                       1.10449144504599e-4 1.01828770740567e-4
+                                       9.41998224204238e-5 8.74130545753834e-5
+                                       8.13466262162801e-5 7.59002269646219e-5
+                                       -0.00149282953213429
+                                       -8.78204709546389e-4
+                                       -5.02916549572035e-4
+                                       -2.94822138512746e-4
+                                       -1.75463996970783e-4
+                                       -1.04008550460816e-4
+                                       -5.96141953046458e-5
+                                       -3.12038929076098e-5 -1.2608973598023e-5
+                                       -2.4289260857573e-7 8.05996165414274e-6
+                                       1.36507009262147e-5 1.73964125472926e-5
+                                       1.98672978842134e-5 2.14463263790823e-5
+                                       2.23954659232457e-5 2.28967783814713e-5
+                                       2.30785389811178e-5 2.30321976080909e-5
+                                       2.28236073720349e-5 2.25005881105292e-5
+                                       2.20981015361991e-5 2.16418427448104e-5
+                                       2.11507649256221e-5 2.06388749782171e-5
+                                       2.01165241997082e-5 5.52213076721293e-4
+                                       4.47932581552385e-4 2.79520653992021e-4
+                                       1.52468156198447e-4 6.93271105657044e-5
+                                       1.76258683069991e-5 -1.35744996343269e-5
+                                       -3.17972413350427e-5
+                                       -4.18861861696693e-5
+                                       -4.69004889379141e-5
+                                       -4.87665447413787e-5
+                                       -4.87010031186735e-5
+                                       -4.74755620890087e-5
+                                       -4.55813058138628e-5
+                                       -4.33309644511266e-5 -4.0923019315775e-5
+                                       -3.84822638603221e-5
+                                       -3.60857167535411e-5
+                                       -3.37793306123367e-5 -3.1588856077211e-5
+                                       -2.95269561750807e-5
+                                       -2.75978914828336e-5
+                                       -2.58006174666884e-5 -2.4130835676128e-5
+                                       -2.25823509518346e-5
+                                       -2.11479656768913e-5 -4.7461779655996e-4
+                                       -4.77864567147321e-4
+                                       -3.20390228067038e-4
+                                       -1.61105016119962e-4
+                                       -4.25778101285435e-5 3.44571294294968e-5
+                                       7.97092684075675e-5 1.03138236708272e-4
+                                       1.12466775262204e-4 1.13103642108481e-4
+                                       1.08651634848774e-4 1.01437951597662e-4
+                                       9.29298396593364e-5 8.4029313301609e-5
+                                       7.52727991349134e-5 6.69632521975731e-5
+                                       5.92564547323195e-5 5.22169308826976e-5
+                                       4.58539485165361e-5 4.01445513891487e-5
+                                       3.50481730031328e-5 3.05157995034347e-5
+                                       2.64956119950516e-5 2.29363633690998e-5
+                                       1.97893056664022e-5 1.70091984636413e-5
+                                       7.36465810572578e-4 8.72790805146194e-4
+                                       6.22614862573135e-4 2.85998154194304e-4
+                                       3.84737672879366e-6 -1.87906003636972e-4
+                                       -2.97603646594555e-4
+                                       -3.45998126832656e-4
+                                       -3.53382470916038e-4
+                                       -3.35715635775049e-4 -3.0432112478904e-4
+                                       -2.66722723047613e-4 -2.2765421412282e-4
+                                       -1.89922611854562e-4
+                                       -1.55058918599094e-4
+                                       -1.23778240761874e-4
+                                       -9.62926147717644e-5
+                                       -7.25178327714425e-5
+                                       -5.22070028895634e-5
+                                       -3.50347750511901e-5
+                                       -2.06489761035552e-5
+                                       -8.70106096849767e-6 1.136986866751e-6
+                                       9.16426474122779e-6 1.56477785428873e-5
+                                       2.08223629482467e-5)))
       (gama
        (make-array 26
                    :element-type 'double-float
@@ -92,11 +250,7 @@
   (defun dasyjy (funjy x fnu flgjy in y wk iflw)
     (declare (type (array double-float (*)) wk y)
              (type f2cl-lib:integer4 iflw in)
-             (type double-float flgjy fnu x)
-             (type (function
-                    (double-float double-float double-float double-float
-                     double-float)
-                    (values &rest t)) funjy))
+             (type double-float flgjy fnu x))
     (f2cl-lib:with-multi-array-data
         ((y double-float y-%data% y-%offset%)
          (wk double-float wk-%data% wk-%offset%))
@@ -122,7 +276,7 @@
                                     fn fi elim dfi crz32 bsum az asum ap akm
                                     abw2))
         (setf ta (f2cl-lib:d1mach 3))
-        (setf tol (max ta 1.0e-15))
+        (setf tol (max ta 1.e-15))
         (setf tb (f2cl-lib:d1mach 5))
         (setf ju (f2cl-lib:i1mach 15))
         (if (= flgjy 1.0) (go label6))
