@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing t) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((rttpi 0.398942280401433) (inlim 80))
@@ -36,7 +36,7 @@
         (setf nz 0)
         (setf kt 1)
         (setf ra (f2cl-lib:d1mach 3))
-        (setf tol (max ra 1.0e-15))
+        (setf tol (max ra 1.e-15))
         (setf i1 (f2cl-lib:int-sub (f2cl-lib:i1mach 15)))
         (setf gln (f2cl-lib:d1mach 5))
         (setf elim (* 2.303 (- (* i1 gln) 3.0)))
