@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
 ;;;           (:array-slicing t) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((x
@@ -23,8 +23,7 @@
          (f a b bl br alfa beta ri rj rg rh result abserr resasc integr nev)
     (declare (type f2cl-lib:integer4 nev integr)
              (type (array double-float (*)) rh rg rj ri)
-             (type double-float resasc abserr result beta alfa br bl b a)
-             (type (function (double-float) (values double-float &rest t)) f))
+             (type double-float resasc abserr result beta alfa br bl b a))
     (f2cl-lib:with-multi-array-data
         ((ri double-float ri-%data% ri-%offset%)
          (rj double-float rj-%data% rj-%offset%)
