@@ -1,15 +1,15 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
 ;;;           (:array-slicing nil) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (defun xerhlt (messg)
   (declare (type (simple-array character (*)) messg))
-  (prog () (declare) end_label (return (values nil))))
+  (prog () (declare) (f2cl-lib::stop nil) end_label (return (values nil))))
 
