@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
 ;;;           (:array-slicing nil) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((tth 0.6666666666666666)
@@ -43,7 +43,7 @@
       (if (or (< kode 1) (> kode 2)) (setf ierr 1))
       (if (/= ierr 0) (go end_label))
       (setf az (zabs zr zi))
-      (setf tol (max (f2cl-lib:d1mach 4) 1.0e-18))
+      (setf tol (max (f2cl-lib:d1mach 4) 1.e-18))
       (setf fid (coerce (the f2cl-lib:integer4 id) 'double-float))
       (if (> az 1.0) (go label70))
       (setf s1r coner)
