@@ -1,12 +1,12 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2005/06/20 01:53:39 
-;;; Using Lisp CMU Common Lisp Snapshot 2005-06 (19B)
+;;; Compiled by f2cl version 2.0 beta Date: 2006/01/31 15:11:05 
+;;; Using Lisp CMU Common Lisp Snapshot 2006-01 (19C)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
 ;;;           (:array-slicing nil) (:declare-common nil)
 ;;;           (:float-format double-float))
 
-(in-package "SLATEC")
+(in-package :slatec)
 
 
 (let ((ar
@@ -60,48 +60,40 @@
                                        -2813563.226586534 1268365.2733216248
                                        -331645.1724845636 45218.76898136273
                                        -2499.8304818112097 24.380529699556064
-                                       3284469.853072038 -1.9706819118432228e+7
-                                       5.095260249266464e+7
-                                       -7.410514821153265e+7
-                                       6.634451227472903e+7
-                                       -3.756717666076335e+7
-                                       1.3288767166421818e+7
-                                       -2785618.1280864547 308186.4046126624
-                                       -13886.08975371704 110.01714026924674
-                                       -4.932925366450996e+7
-                                       3.2557307418576574e+8
-                                       -9.394623596815784e+8
-                                       1.55359689957058e+9
-                                       -1.6210805521083372e+9
-                                       1.1068428168230145e+9
-                                       -4.958897842750303e+8
-                                       1.420629077975331e+8
-                                       -2.447406272573873e+7 2243768.1779224495
+                                       3284469.853072038 -1.9706819118432228e7
+                                       5.095260249266464e7 -7.410514821153265e7
+                                       6.634451227472903e7 -3.756717666076335e7
+                                       1.3288767166421818e7 -2785618.1280864547
+                                       308186.4046126624 -13886.08975371704
+                                       110.01714026924674 -4.932925366450996e7
+                                       3.2557307418576574e8
+                                       -9.394623596815784e8 1.55359689957058e9
+                                       -1.6210805521083372e9
+                                       1.1068428168230145e9
+                                       -4.958897842750303e8 1.420629077975331e8
+                                       -2.447406272573873e7 2243768.1779224495
                                        -84005.43360302408 551.3358961220206
-                                       8.147890961183121e+8
-                                       -5.866481492051847e+9
-                                       1.8688207509295826e+10
-                                       -3.4632043388158775e+10
-                                       4.1280185579753975e+10
-                                       -3.3026599749800724e+10
-                                       1.79542137311556e+10
-                                       -6.563293792619285e+9
-                                       1.5592798648792574e+9
-                                       -2.2510566188941526e+8
-                                       1.7395107553978164e+7 -549842.3275722887
-                                       3038.090510922384
-                                       -1.4679261247695616e+10
-                                       1.144982377320258e+11
-                                       -3.990961752244665e+11
-                                       8.192186695485773e+11
-                                       -1.0983751560812233e+12
-                                       1.0081581068653821e+12
-                                       -6.453648692453765e+11
-                                       2.879006499061506e+11
-                                       -8.786707217802327e+10
-                                       1.763473060683497e+10
-                                       -2.167164983223795e+9
-                                       1.4315787671888897e+8 -3871833.442572613
+                                       8.147890961183121e8 -5.866481492051847e9
+                                       1.8688207509295826e10
+                                       -3.4632043388158775e10
+                                       4.1280185579753975e10
+                                       -3.3026599749800724e10
+                                       1.79542137311556e10 -6.563293792619285e9
+                                       1.5592798648792574e9
+                                       -2.2510566188941526e8
+                                       1.7395107553978164e7 -549842.3275722887
+                                       3038.090510922384 -1.4679261247695616e10
+                                       1.144982377320258e11
+                                       -3.990961752244665e11
+                                       8.192186695485773e11
+                                       -1.0983751560812233e12
+                                       1.0081581068653821e12
+                                       -6.453648692453765e11
+                                       2.879006499061506e11
+                                       -8.786707217802327e10
+                                       1.763473060683497e10
+                                       -2.167164983223795e9
+                                       1.4315787671888897e8 -3871833.442572613
                                        18257.755474293175)))
       (alfa
        (make-array 180
