@@ -530,7 +530,7 @@
 (defun properties (x)
   (do ((y (symbol-plist x) (cddr y))
        (l (cons '(mlist simp) (and (boundp x)
-				   (if (optionp x) (ncons '|&SYSTEM VALUE|)
+				   (if (optionp x) (ncons (make-mstring "system value"))
 				       (ncons '$value)))))
        (prop))
       ((null y)
@@ -540,13 +540,13 @@
        (if (memq x (cdr $activecontexts))
 	   (nconc l (ncons '$activecontext)))
        (cond  ((null (symbol-plist x))
-	       (if (fboundp x) (nconc l (list '|&SYSTEM FUNCTION|)))))
+	       (if (fboundp x) (nconc l (list (make-mstring "system function"))))))
        l)
     ;; TOP-LEVEL PROPERTIES 
     (cond ((setq prop (assq (car y)
-			    '((bindtest . $bindtest)
+			    `((bindtest . $bindtest)
 			      (sp2 . $deftaylor) (sp2subs . $deftaylor)
-			      (assign . |&ASSIGN PROPERTY|)
+			      (assign . ,(make-mstring "assign property"))
 			      (nonarray . $nonarray) (grad . $gradef)
 			      (noun . $noun) (evfun . $evfun) (special . $special)
 			      (evflag . $evflag) (op . $operator) (alphabet . $alphabetic))))
@@ -555,22 +555,22 @@
 	  ((and (eq (car y) 'operators) (not (eq (cadr y) 'simpargs1)))
 	   (nconc l (list '$rule)))
 	  ((and (memq (car y) '(fexpr fsubr mfexpr*s mfexpr*))
-		(nconc l (ncons '|&SPECIAL EVALUATION FORM|))
+		(nconc l (ncons (make-mstring "special evaluation form")))
 		nil))
 	  ((and (or (get (car y) 'mfexpr*) (fboundp x))
-		(not (memq '|&SYSTEM FUNCTION| l)))
+		(not (memq (make-mstring "system function") l)))
 	   (nconc l
 		  (list (cond ((get x 'translated) '$transfun)
 			      ((mgetl x '($rule ruleof)) '$rule)
-			      (t '|&SYSTEM FUNCTION|)))))
-	  ((and (eq (car y) 'autoload) (not (memq '|&SYSTEM FUNCTION| l)))
+			      (t (make-mstring "system function"))))))
+	  ((and (eq (car y) 'autoload) (not (memq (make-mstring "system function") l)))
 	   (nconc l (ncons (if (memq x (cdr $props))
-			       '|&USER AUTOLOAD FUNCTION|
-			       '|&SYSTEM FUNCTION|))))
+			       (make-mstring "user autoload function")
+			       (make-mstring "system function")))))
 	  ((and (eq (car y) 'reversealias) (memq (car y) (cdr $aliases)))
 	   (nconc l (ncons '$alias)))
 	  ((eq (car y) 'data)
-	   (nconc l (cons '|&DATABASE INFO| (cdr ($facts x)))))
+	   (nconc l (cons (make-mstring "database info") (cdr ($facts x)))))
 	  ((eq (car y) 'mprops)
 	   ;; PROPS PROPERTIES
 	   (do ((y
@@ -578,10 +578,10 @@
 		 (cddr y)))
 	       ((null y))
 	     (cond ((setq prop (assq (car y)
-				     '((mexpr . $function)
+				     `((mexpr . $function)
 				       (mmacro . $macro)
-				       (hashar . |&HASHED ARRAY|)
-				       (aexpr . |&ARRAY FUNCTION|)
+				       (hashar . ,(make-mstring "hashed array"))
+				       (aexpr . ,(make-mstring "array function"))
 				       (atvalues . $atvalue)
 				       ($atomgrad . $atomgrad)
 				       ($numer . $numer)
@@ -594,12 +594,12 @@
 		    (nconc l (list (cdr prop))))
 		   ((eq (car y) 'array)
 		    (nconc l
-			   (list (cond ((get x 'array) '|&COMPLETE ARRAY|)
-				       (t '|&DECLARED ARRAY|)))))
+			   (list (cond ((get x 'array) (make-mstring "complete array"))
+				       (t (make-mstring "declared array"))))))
 		   ((and (eq (car y) '$props) (cdadr y))
 		    (nconc l
 			   (do ((y (cdadr y) (cddr y))
-				(l (list '(mlist) '|&USER PROPERTIES|)))
+				(l (list '(mlist) (make-mstring "user properties"))))
 			       ((null y) (list l))
 			     (nconc l (list (car y))))))))))))
 
