@@ -7,7 +7,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; ** (c) Copyright 1980 Massachusetts Institute of Technology **
 
-(in-package "MAXIMA")
+(in-package :maxima)
 (macsyma-module psolve)
 
 (declare-top(genprefix pso)
