@@ -1,7 +1,7 @@
 
 ;; very simple server started on port
 
-(in-package "MAXIMA")
+(in-package :maxima)
 
 #+sbcl
 (eval-when (:compile-toplevel :load-toplevel :execute)
@@ -39,9 +39,9 @@
                                   :format (if bin :binary :text))
     #+clisp (socket:socket-connect port host :element-type
 				   (if bin '(unsigned-byte 8) 'character))
-    #+cmu (sys:make-fd-stream (ext:connect-to-inet-socket host port)
-                              :input t :output t :element-type
-                              (if bin '(unsigned-byte 8) 'character))
+    #+(or cmu scl) (sys:make-fd-stream (ext:connect-to-inet-socket host port)
+				       :input t :output t :element-type
+				       (if bin '(unsigned-byte 8) 'character))
     #+sbcl (let ((socket (make-instance 'sb-bsd-sockets:inet-socket
 					:type :stream :protocol :tcp)))
 	     (sb-bsd-sockets:socket-connect
@@ -53,7 +53,7 @@
     #+gcl (si::socket port :host host)
     #+lispworks (comm:open-tcp-stream host port :direction :io :element-type
                                       (if bin 'unsigned-byte 'base-char))
-    #-(or allegro clisp cmu sbcl gcl lispworks)
+    #-(or allegro clisp cmu scl sbcl gcl lispworks)
     (error 'not-implemented :proc (list 'open-socket host port bin))))
 
 
@@ -78,17 +78,17 @@
 			   (find-symbol "PROGRAM-ID" "SYS")))
 		  'getpid-from-environment)))
 
-#+cmu
+#+(or cmu scl)
 (defun getpid () (unix:unix-getpid))
 
 #+sbcl
 (defun getpid () (sb-unix:unix-getpid))
 
-#+(or gcl clisp cmu sbcl)
+#+(or gcl clisp cmu scl sbcl)
 (defun xchdir (w)
   #+clisp (ext:cd w)
   #+gcl (si::chdir w)
-  #+cmu (unix::unix-chdir w)
+  #+(or cmu scl) (unix::unix-chdir w)
   #+sbcl (sb-posix:chdir w)
   )
  
