@@ -10,7 +10,7 @@
 ;;;       (c) Copyright 1980 Massachusetts Institute of Technology       ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(in-package "MAXIMA")
+(in-package :maxima)
 (macsyma-module transm macro)
 (load-macsyma-macros procs)
 (load-macsyma-macros-at-runtime 'procs)
@@ -242,7 +242,7 @@
 ;;#+PDP10
 ;;(PROGN 'COMPILE
 
-;;(defun get! (a b) (or (get a b) (get! (MAXIMA-ERROR (list "undefined" b "property")
+;;(defun get! (a b) (or (get a b) (get! (maxima-error (list "undefined" b "property")
 ;;					     a 'wrng-type-arg)
 ;;				      b)))
 
@@ -294,7 +294,7 @@
 ;;	 stream)
 ;;  (print `(map1-put-if-nil ',(get module 'tr-props)
 ;;			   (or (get 'autoload-translate 'subr)
-;;			       (MAXIMA-ERROR 'autoload-translate 'subr
+;;			       (maxima-error 'autoload-translate 'subr
 ;;				      'fail-act))
 ;;			   'translate)
 ;;	 stream)
@@ -585,3 +585,27 @@
 
 
 
+#+cl
+(defmacro maset ( val ar  &rest inds)
+  `(progn
+     (cond ((symbolp ,ar)
+	    (setf ,ar (make-equal-hash-table
+		       ,(if (cdr inds) t nil)))))
+    (maset1 ,val  ,ar ,@  inds)))
+
+
+;;#+lispm  ;;removed the apply from tr-arraycall and &rest.
+;;(defun tr-maref (ar &rest inds)
+;;    `(nil maref ,ar ,@ (copy-list inds)))
+
+
+
+(defmacro maref (ar &rest inds)
+  (cond ((or (eql ar 'mqapply)(and (consp ar) (memq 'mqapply ar)))
+         `(marrayref ,(first inds) ,@ (cdr inds)))
+	((consp ar)`(marrayref ,ar ,(first inds) ,@ (cdr inds)))
+	(t
+	 `(maref1  ,ar,@ inds))))
+
+
+
